@@ -30,7 +30,7 @@ typedef Eina_Future * (*EflFilterModel)(void *data, Efl_Filter_Model *parent, Ef
  */
 #define EFL_FILTER_MODEL_CLASS efl_filter_model_class_get()
 
-EWAPI const Efl_Class *efl_filter_model_class_get(void);
+EWAPI const Efl_Class *efl_filter_model_class_get(void) EINA_CONST;
 
 /**
  * @brief Set a filter function that will catch children from the composited
