@@ -198,7 +198,7 @@ typedef struct _Efl_Net_Dialer_Websocket_Closed_Reason
  */
 #define EFL_NET_DIALER_WEBSOCKET_CLASS efl_net_dialer_websocket_class_get()
 
-EWAPI const Efl_Class *efl_net_dialer_websocket_class_get(void);
+EWAPI const Efl_Class *efl_net_dialer_websocket_class_get(void) EINA_CONST;
 
 /**
  * @brief Sends a PING (opcode=0x9) to the server.
