@@ -13,12 +13,14 @@ typedef Eo Efl_Canvas_Vg_Gradient_Radial;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl vector graphics gradient radial class
  *
  * @ingroup Efl_Canvas_Vg_Gradient_Radial
  */
 #define EFL_CANVAS_VG_GRADIENT_RADIAL_CLASS efl_canvas_vg_gradient_radial_class_get()
 
-EWAPI const Efl_Class *efl_canvas_vg_gradient_radial_class_get(void);
+EWAPI const Efl_Class *efl_canvas_vg_gradient_radial_class_get(void) EINA_CONST;
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
